Crate x509_test_certs

Crate x509_test_certs 

Pre-built X509 certificates.

This crate provides cryptographic certificates and keys, meant for testing TLS clients and servers.

The certificates are meant to look realistic: they have most of the extensions that real-world certificates have, and try to follow the CAB guidelines as a real CA would.

This crate contains no code or dependencies, just const byte arrays containing pre-generated certificates and private keys.

If you would like to generate your own certificates, please try the x509-test-gen crate. It contains the code that was used to generate the certificates in the x509-test-certs crate.

Modules

bad_certs1
CA and improperly signed server certificates.
good_certs1
A collection of CA, client and server certificates.
good_certs2
A collection of CA, intermediate, client and server certificates
good_certs3
A client certificate with additional name types.