Pre-built X509 certificates.
This crate provides cryptographic certificates and keys, meant for testing TLS clients and servers.
The certificates are meant to look realistic: they have most of the extensions that real-world certificates have, and try to follow the CAB guidelines as a real CA would.
This crate contains no code or dependencies, just const byte arrays containing
pre-generated certificates and private keys.
If you would like to generate your own certificates, please try the x509-test-gen
crate. It contains the code that was used to generate the certificates in the
x509-test-certs crate.
Modules
- bad_
certs1 - CA and improperly signed server certificates.
- good_
certs1 - A collection of CA, client and server certificates.
- good_
certs2 - A collection of CA, intermediate, client and server certificates
- good_
certs3 - A client certificate with additional name types.